summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/spinbox2.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kalarm/lib/spinbox2.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/lib/spinbox2.cpp')
-rw-r--r--kalarm/lib/spinbox2.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kalarm/lib/spinbox2.cpp b/kalarm/lib/spinbox2.cpp
index 8b3faa706..8627838b6 100644
--- a/kalarm/lib/spinbox2.cpp
+++ b/kalarm/lib/spinbox2.cpp
@@ -1,5 +1,5 @@
/*
- * spinbox2.cpp - spin box with extra pair of spin buttons (for Qt 3)
+ * spinbox2.cpp - spin box with extra pair of spin buttons (for TQt 3)
* Program: kalarm
* Copyright © 2001-2005,2008 by David Jarvie <djarvie@kde.org>
*
@@ -48,8 +48,8 @@ static bool mirrorStyle(const TQStyle&);
int SpinBox2::mReverseLayout = -1;
-SpinBox2::SpinBox2(TQWidget* parent, const char* name)
- : TQFrame(parent, name),
+SpinBox2::SpinBox2(TQWidget* tqparent, const char* name)
+ : TQFrame(tqparent, name),
mReverseWithLayout(true)
{
mUpdown2Frame = new TQFrame(this);
@@ -60,8 +60,8 @@ SpinBox2::SpinBox2(TQWidget* parent, const char* name)
init();
}
-SpinBox2::SpinBox2(int minValue, int maxValue, int step, int step2, TQWidget* parent, const char* name)
- : TQFrame(parent, name),
+SpinBox2::SpinBox2(int minValue, int maxValue, int step, int step2, TQWidget* tqparent, const char* name)
+ : TQFrame(tqparent, name),
mReverseWithLayout(true)
{
mUpdown2Frame = new TQFrame(this);
@@ -371,7 +371,7 @@ int SpinBox2::MainSpinBox::shiftStepAdjustment(int oldValue, int shiftStep)
/******************************************************************************
* Repaint the widget.
* If it's the first time since a style change, tell the parent SpinBox2 to
* update the SpinMirror with the new unpressed button image. We make the
* presumably reasonable assumption that when a style change occurs, the spin
* buttons are unpressed.
@@ -391,8 +391,8 @@ void ExtraSpinBox::paintEvent(TQPaintEvent* e)
= Class SpinMirror
=============================================================================*/
-SpinMirror::SpinMirror(SpinBox* spinbox, TQFrame* spinFrame, TQWidget* parent, const char* name)
- : TQCanvasView(new TQCanvas, parent, name),
+SpinMirror::SpinMirror(SpinBox* spinbox, TQFrame* spinFrame, TQWidget* tqparent, const char* name)
+ : TQCanvasView(new TQCanvas, tqparent, name),
mSpinbox(spinbox),
mSpinFrame(spinFrame),
mReadOnly(false)
@@ -371,7 +371,7 @@ int SpinBox2::MainSpinBox::shiftStepAdjustment(int oldValue, int shiftStep)
/******************************************************************************
* Repaint the widget.
-* If it's the first time since a style change, tell the parent SpinBox2 to
+* If it's the first time since a style change, tell the tqparent SpinBox2 to
* update the SpinMirror with the new unpressed button image. We make the
* presumably reasonable assumption that when a style change occurs, the spin